import QtQuick 2.4
import QtMultimedia 5.6
import org.nemomobile.mpris 1.0

Item
{
    property var player: null
    property var meta: null
    property var playlist: null

    MprisPlayer
    {
        serviceName: "lomiri-music-app"
        supportedUriSchemes: ["file"]
        canQuit: false
        canRaise: false
        canSetFullscreen: false
        hasTrackList: false
        desktopEntry: "lomiri-music-app"
        identity: "Lomiri Music App"
        canControl: playlist ? playlist.itemCount : false
        canPlay: true
        canGoNext: playlist ? playlist.canGoNext : false
        canGoPrevious: playlist ? playlist.canGoPrevious : false
        canPause: true
        canSeek: false
        playbackStatus: (!player ? Mpris.Stopped : player.playbackState == MediaPlayer.PlayingState ? Mpris.Playing : player.playbackState == MediaPlayer.PausedState ? Mpris.Paused : Mpris.Stopped)
        metadata:
        {
            let pMetadata = {};

            if (meta)
            {
                if (meta.author != null)
                {
                    pMetadata["xesam:artist"] = [meta.author];
                }

                if (meta.title != null)
                {
                    pMetadata["xesam:title"] = meta.title;
                }

                if (meta.album != null)
                {
                    pMetadata["xesam:album"] = meta.album;
                }

                if (meta.art != null)
                {
                    pMetadata["mpris:artUrl"] = meta.art;
                }
            }

            return pMetadata;
        }

        onPlayRequested:
        {
            player.play ();
        }

        onPauseRequested:
        {
            player.pause ();
        }

        onNextRequested:
        {
            playlist.nextWrapper ();
            player.play ();
        }

        onPreviousRequested:
        {
            playlist.previousWrapper ();
            player.play ();
        }

        onStopRequested:
        {
            player.stop ();
        }

        onPlayPauseRequested:
        {
            player.toggle ();
        }
    }
}
